@@ -2,49 +2,19 @@
 
 #include <RcppArmadillo.h>
 #include "mn.h"
-#include "templates.h"
+#include "Rfast.h"
 #ifdef _OPENMP
 #include <omp.h>
 #endif
 
 using namespace Rcpp;
 
-NumericMatrix transpose_sq(NumericMatrix x){
-  int i,ncl=x.ncol(),u;
-  NumericMatrix f=clone(x);
-  for(i=1;i<ncl;++i)
-    for(u=0;u<i;++u)
-    	swap(f(u,i),f(i,u));
-  return f;
-}
-
-RcppExport SEXP Rfast_transpose_sq(SEXP xSEXP) {
+RcppExport SEXP Rfast_transpose(SEXP xSEXP) {
 BEGIN_RCPP
     RObject __result;
     RNGScope __rngScope;
     traits::input_parameter< NumericMatrix >::type x(xSEXP);
-    __result = transpose_sq(x);
-    return __result;
-END_RCPP
-}
-
-NumericMatrix Rfast_transpose_g_p(NumericMatrix x){
-    int i,p=x.ncol(),n=x.nrow();
-    NumericMatrix f(p,n);
-    mat ff(f.begin(),p,n,false),xx(x.begin(),n,p,false);
-#pragma omp parallel for
-    for(i=0;i<p;++i){
-      ff.row(i)=xx.col(i).t();
-  }
-    return f;
-}
-
-RcppExport SEXP Rfast_transpose_g_p(SEXP xSEXP) {
-BEGIN_RCPP
-    RObject __result;
-    RNGScope __rngScope;
-    traits::input_parameter< NumericMatrix >::type x(xSEXP);
-    __result = Rfast_transpose_g_p(x);
+    __result = wrap(Rfast::matrix::transpose(x));
     return __result;
 END_RCPP
 }
@@ -71,7 +41,7 @@ BEGIN_RCPP
     RNGScope __rngScope;
     traits::input_parameter< NumericMatrix >::type x(xSEXP);
     traits::input_parameter< NumericMatrix >::type y(ySEXP);
-    __result = mat_mat(x,y);
+    __result = wrap(mat_mat(x,y));
     return __result;
 END_RCPP
 }
@@ -80,28 +50,13 @@ END_RCPP
 ////////////////////////////////////////////////////////////////////////////////////////
 
 
-mat mat_mult_p(NumericMatrix X,NumericMatrix Y){
-    const int n=X.ncol(),p=Y.ncol();
-    mat f(n,p),x(X.begin(),X.nrow(),n,false),y(Y.begin(),Y.nrow(),p,false);
-    colvec yi(y.n_rows);
-    for(int i=0;i<p;++i){
-        yi=y.col(i);
-        #ifdef _OPENMP
-        #pragma omp parallel for
-        #endif
-        for(int j=0;j<n;++j)
-            f(j,i)=dot(x.col(j),yi);
-    }
-    return f;
-}
-
 RcppExport SEXP Rfast_mat_mult_p(SEXP xSEXP,SEXP ySEXP) {
 BEGIN_RCPP
     RObject __result;
     RNGScope __rngScope;
     traits::input_parameter< NumericMatrix >::type x(xSEXP);
     traits::input_parameter< NumericMatrix >::type y(ySEXP);
-    __result = mat_mult_p(x,y);
+    __result = wrap(Rfast::matrix::matrix_multiplication(x,y));
     return __result;
 END_RCPP
 }
@@ -123,7 +78,7 @@ BEGIN_RCPP
     traits::input_parameter< const int >::type rowend(rowendSEXP);
     traits::input_parameter< const int >::type colstart(colstartSEXP);
     traits::input_parameter< const int >::type colend(colendSEXP);
-    __result = submatrix(x,rowstart,rowend,colstart,colend);
+    __result = wrap(submatrix(x,rowstart,rowend,colstart,colend));
     return __result;
 END_RCPP
 }
@@ -145,7 +100,7 @@ BEGIN_RCPP
     RObject __result;
     RNGScope __rngScope;
     traits::input_parameter< const char  >::type oper(operSEXP);
-    __result = sum_XopY(x,y,oper);
+    __result = wrap(sum_XopY(x,y,oper));
     return __result;
 END_RCPP
 }
@@ -169,7 +124,7 @@ BEGIN_RCPP
     RObject __result;
     RNGScope __rngScope;
     traits::input_parameter< const char  >::type oper(operSEXP);
-    __result = sum_XopX(x,oper);
+    __result = wrap(sum_XopX(x,oper));
     return __result;
 END_RCPP
 }
