@@ -3,6 +3,9 @@
 #include <RcppArmadillo.h>
 #include <dirent.h>
 #include "system_files.h"
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
 
 using namespace Rcpp;
 
@@ -35,7 +38,7 @@ BEGIN_RCPP
     RObject __result;
     RNGScope __rngScope;
     traits::input_parameter< const string >::type path(pathSEXP);
-    __result = read_directory(path);
+    __result = wrap(read_directory(path));
     return __result;
 END_RCPP
 }
@@ -43,6 +46,12 @@ END_RCPP
 
 /////////////////////////////////////////////////////////////////////////
 
+int is_regular_file(const char *path)
+{
+    struct stat path_stat;
+    stat(path, &path_stat);
+    return S_ISREG(path_stat.st_mode);
+}
 
 using std::ifstream;
 using std::vector;
@@ -54,24 +63,28 @@ List read_examples(string path_man){
   string tmp;
   int longlines=0;
   for(unsigned int i=0;i<all_rd_files.size();++i){
-    file.open(path_man+all_rd_files[i]);
-    if(!file.is_open()){
-      stop("Can't open file \"%s\".",all_rd_files[i]);
-    }
-    if(check_read_file(file,'%')){
-      longlines=0;
-      tmp=read_example(file,longlines);
-      if(longlines){
-      	files_long_lines.push_back(all_rd_files[i]);
-      }
-      examples.push_back(tmp);
-    }else{
-      DEBUG("Find attribute dont read file with name: "+all_rd_files[i]);
-      dontread_rd.push_back(all_rd_files[i]);
-      all_rd_files.erase(all_rd_files.begin()+i);
-      --i;
-    }
-    file.close();
+  	string filename = path_man+all_rd_files[i];
+  	if(is_regular_file(filename.c_str())){
+	    file.open(filename);
+	    if(!file.is_open()){
+	      stop("Can't open file \"%s\".",all_rd_files[i]);
+	    }
+	    if(check_read_file(file,'%')){
+	      longlines=0;
+	      tmp=read_example(file,longlines);
+	      if(longlines){
+	      	files_long_lines.push_back(all_rd_files[i]);
+	      }
+	      if(!tmp.empty())
+	        examples.push_back(tmp);
+	    }else{
+	      DEBUG("Find attribute dont read file with name: "+all_rd_files[i]);
+	      dontread_rd.push_back(all_rd_files[i]);
+	      all_rd_files.erase(all_rd_files.begin()+i);
+	      --i;
+	    }
+	    file.close();
+	}
   }
   List l;
   l["examples"]=examples;
@@ -86,7 +99,7 @@ BEGIN_RCPP
     RObject __result;
     RNGScope __rngScope;
     traits::input_parameter< string >::type path_man(path_manSEXP);
-    __result = read_examples(path_man);
+    __result = wrap(read_examples(path_man));
     return __result;
 END_RCPP
 }
